==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/types3/StructWithOccuringStruct.java <==

package org.apache.type_test.types3;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithOccuringStruct complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithOccuringStruct">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varInteger" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *           &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *           &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;/sequence>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithOccuringStruct", propOrder = {
    "varInteger",
    "varIntAndVarFloat"
})
public class StructWithOccuringStruct {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected int varInteger;
    @XmlElements({
        @XmlElement(name = "varFloat", namespace = "http://apache.org/type_test/types3", required = true, type = Float.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class)
    })
    protected List<Comparable> varIntAndVarFloat;

    /**
     * Gets the value of the varInteger property.
     * 
     */
    public int getVarInteger() {
        return varInteger;
    }

    /**
     * Sets the value of the varInteger property.
     * 
     */
    public void setVarInteger(int value) {
        this.varInteger = value;
    }

    /**
     * Gets the value of the varIntAndVarFloat property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varIntAndVarFloat property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarIntAndVarFloat().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Float }
     * {@link Integer }
     * 
     * 
     */
    public List<Comparable> getVarIntAndVarFloat() {
        if (varIntAndVarFloat == null) {
            varIntAndVarFloat = new ArrayList<Comparable>();
        }
        return this.varIntAndVarFloat;
    }

}

==> cxf-testutils-2.0.12.0-fuse-sources.jar: org/apache/type_test/types3/StructWithOccuringStruct.java <==

package org.apache.type_test.types3;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for StructWithOccuringStruct complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithOccuringStruct">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varInteger" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *           &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *           &lt;element name="varFloat" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *         &lt;/sequence>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithOccuringStruct", propOrder = {
    "varInteger",
    "varIntAndVarFloat"
})
public class StructWithOccuringStruct {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected int varInteger;
    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types3", required = true, type = Integer.class),
        @XmlElement(name = "varFloat", namespace = "http://apache.org/type_test/types3", required = true, type = Float.class)
    })
    protected List<Comparable> varIntAndVarFloat;

    /**
     * Gets the value of the varInteger property.
     * 
     */
    public int getVarInteger() {
        return varInteger;
    }

    /**
     * Sets the value of the varInteger property.
     * 
     */
    public void setVarInteger(int value) {
        this.varInteger = value;
    }

    /**
     * Gets the value of the varIntAndVarFloat property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varIntAndVarFloat property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarIntAndVarFloat().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link Float }
     * 
     * 
     */
    public List<Comparable> getVarIntAndVarFloat() {
        if (varIntAndVarFloat == null) {
            varIntAndVarFloat = new ArrayList<Comparable>();
        }
        return this.varIntAndVarFloat;
    }

}
